import * as i0 from '@angular/core';
import { EventEmitter, Injectable, Component, Input, Output, ViewChild } from '@angular/core';
import * as i3 from '@po-ui/ng-components';
import { PoModalComponent, PoModule } from '@po-ui/ng-components';
import * as i4$1 from 'angularx-qrcode';
import { QRCodeModule } from 'angularx-qrcode';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i5 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as signalR from '@microsoft/signalr';
import * as i1 from '@angular/common/http';
import { HttpHeaders } from '@angular/common/http';
import * as i4 from 'ngx-image-compress';

class SignalRService {
    constructor() {
        this.host = '';
        this.messageReceived = new EventEmitter();
    }
    initializeConnection(projectID) {
        this.hubConnection = new signalR.HubConnectionBuilder()
            .withUrl(`${this.host}/notification`, {
            transport: signalR.HttpTransportType.LongPolling,
            withCredentials: false,
            headers: {
                'IDPROJETO': projectID
            }
        })
            .configureLogging(signalR.LogLevel.Information)
            .withAutomaticReconnect()
            .build();
        this.hubConnection.onclose(() => {
            console.error('Connection closed');
        });
    }
    async startConnection() {
        if (this.hubConnection?.state === signalR.HubConnectionState.Connected) {
            await this.hubConnection.stop();
        }
        try {
            await this.hubConnection?.start();
        }
        catch (err) {
            console.error("Error iniciar Hub:", err);
        }
    }
    async joinSession(sessionID) {
        try {
            if (this.hubConnection?.state === signalR.HubConnectionState.Connected) {
                await this.hubConnection.invoke('JoinSession', sessionID);
            }
        }
        catch (err) {
            console.error("Error ao iniciar session:", err);
        }
    }
    async leaveSession(sessionID) {
        try {
            if (this.hubConnection?.state === signalR.HubConnectionState.Connected) {
                await this.hubConnection.invoke('LeaveSession', sessionID);
            }
        }
        catch (err) {
            console.error("Error sair da session:", err);
        }
    }
    async formsLocal(sessionID, body) {
        try {
            if (this.hubConnection?.state === signalR.HubConnectionState.Connected) {
                await this.hubConnection.invoke('SendMessage', sessionID, body);
            }
        }
        catch (err) {
            console.error(err);
        }
        return undefined;
    }
    listenForMessageUnique() {
        this.hubConnection?.on("ReceiveMessage", (message) => {
            const documentResponse = JSON.parse(message);
            const uniqueKey = new Date().getTime();
            this.messageReceived.emit({ menssagem: documentResponse, uniqueKey });
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SignalRService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SignalRService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SignalRService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: () => [] });

class SessionIdApi {
    constructor(http) {
        this.http = http;
    }
    post(host, idTotvsVision, idProjeto, buttonDocumentModel) {
        let headers = new HttpHeaders();
        headers = headers.set('Content-Type', 'application/json');
        headers = headers.set('IDTOTVS', `${idTotvsVision}`);
        headers = headers.set('IDPROJETO', `${idProjeto}`);
        return this.http.post(`${host}/api/totvs-vision-ocr/session-id`, buttonDocumentModel, { headers });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SessionIdApi, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SessionIdApi, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: SessionIdApi, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: i1.HttpClient }] });

class TotvsVisionOcrListComponent {
    ngOnDestroy() {
        if (this.sessionID) {
            this.signalRService.leaveSession(this.sessionID);
            sessionStorage.removeItem('totvsvisionocrdata');
        }
    }
    ngOnInit() {
        this.signalRService.host = "http://127.0.0.1:5002";
        this.validateSession();
        this.openListModal();
        this.initializeSignalRConnection();
    }
    async initializeSignalRConnection() {
        try {
            if (this.sessionID && this.idProjeto) {
                this.signalRService.initializeConnection(this.idProjeto);
                this.signalRService.startConnection().then(() => {
                    this.joinSession(this.sessionID ?? "");
                }).catch(err => console.error(err));
                this.signalRService.messageReceived.subscribe((data) => {
                    this.informacaoEnviada.emit(data);
                });
                this.signalRService.listenForMessageUnique();
            }
        }
        catch (error) {
            this.clearSessionID();
            console.error(error);
        }
    }
    joinSession(sessionID) {
        this.signalRService.joinSession(sessionID).then().catch(err => console.error(err));
    }
    openListModal() {
        if (this.sessionID === null) {
            this.getSessionID();
        }
        if (this.listModal) {
            this.listModal.open();
        }
    }
    closeListModal() {
        if (this.listModal) {
            this.listModal.close();
        }
    }
    constructor(signalRService, sessionIdApi, poNotificationService, imageCompress) {
        this.signalRService = signalRService;
        this.sessionIdApi = sessionIdApi;
        this.poNotificationService = poNotificationService;
        this.imageCompress = imageCompress;
        this.idTotvsVision = '';
        this.idProjeto = '';
        this.listButtonsDocument = [];
        this.informacaoEnviada = new EventEmitter();
        this.loading = false;
        this.screenLock = false;
        this.sessionID = null;
        this.sessionTimeLeft = '';
        this.myAngularxQrCode = sessionStorage.getItem('totvsvisionocrqrCode') ?? '';
        this.documentos = [];
        this.documentosName = [];
        this.selectedButtons = [];
    }
    validateSession() {
        const ocr = sessionStorage.getItem('totvsvisionocrdata');
        if (!ocr) {
            return;
        }
        const objectOCR = JSON.parse(ocr);
        this.sessionID = objectOCR.sessionID;
        const expirationTime = new Date(objectOCR.createdAt);
        expirationTime.setMinutes(expirationTime.getMinutes() + 11);
        this.startCountdown(expirationTime);
    }
    getShortFileName(fileName) {
        if (!fileName)
            return '';
        const prefix = 'Arquivo: ';
        const maxFileNameLength = 30;
        const shortFileName = fileName.length > maxFileNameLength
            ? fileName.substring(0, maxFileNameLength) + '...'
            : fileName;
        return prefix + shortFileName;
    }
    onFileSelected(event, buttonDocumentModel, index) {
        const file = event.target.files[0];
        if (!file.type.startsWith('image/')) {
            this.poNotificationService.error('O arquivo selecionado não é uma imagem');
            return;
        }
        if (file) {
            const reader = new FileReader();
            reader.onload = () => {
                const image = reader.result;
                this.compressImage(image, 95).then((result) => {
                    if (result) {
                        console.log(result);
                        const base64Image = result;
                        this.documentosName[index] = file.name;
                        this.documentos[index] = {
                            imageReturn: buttonDocumentModel.imageReturn,
                            idButton: buttonDocumentModel.idButton,
                            imageBase64: base64Image,
                            jsonImage: buttonDocumentModel.jsonButon
                        };
                        event.target.value = '';
                    }
                });
                event.target.value = '';
            };
            reader.readAsDataURL(file);
        }
    }
    async compressImage(image, quality = 95) {
        const maxSize = 2 * 1024 * 1024; // 2MB em bytes
        try {
            const compressedImage = await this.imageCompress.compressFile(image, -1, 100, quality);
            const sizeInBytes = this.imageCompress.byteCount(compressedImage);
            if (sizeInBytes > maxSize) {
                if (quality > 10) {
                    return this.compressImage(image, quality - 5); // Reduzir a qualidade em incrementos menores
                }
                else {
                    this.poNotificationService.error('Não foi possível reduzir a imagem abaixo de 2 MB mantendo a qualidade mínima.');
                    return null;
                }
            }
            else {
                return compressedImage;
            }
        }
        catch (error) {
            console.error('Erro na compressão da imagem:', error);
            this.poNotificationService.error('Erro na compressão da imagem.');
            return null;
        }
    }
    async enviarImagens() {
        try {
            if (this.documentos.length === 0) {
                this.poNotificationService.error('Nenhum documento selecionado');
                return;
            }
            this.loading = true;
            this.screenLock = true;
            const documentoFiltrados = this.documentos.filter((doc) => doc !== null);
            const result = await this.signalRService.formsLocal(this.sessionID, documentoFiltrados);
            if (result === null || result == undefined) {
                this.poNotificationService.error('Erro ao enviar documentos');
                return;
            }
            this.poNotificationService.success('Documentos enviados com sucesso');
            this.informacaoEnviada.emit({
                menssagem: result,
                uniqueKey: Date.now()
            });
            this.closeListModal();
        }
        catch (error) {
            this.poNotificationService.error('Erro ao enviar documentos');
        }
        finally {
            this.loading = false;
            this.screenLock = false;
        }
    }
    limparImagens() {
        this.documentosName = [];
        this.documentos = [];
        this.selectedButtons = [];
        this.listButtonsDocument.forEach((_, index) => {
            const fileInput = document.getElementById('fileInput' + index);
            if (fileInput) {
                fileInput.value = '';
            }
        });
    }
    onCheckboxChange(checked, index) {
        if (checked) {
            this.selectedButtons.push(index);
        }
        else {
            const position = this.selectedButtons.indexOf(index);
            if (position > -1) {
                this.selectedButtons.splice(position, 1);
            }
        }
    }
    isSelected(index) {
        return this.selectedButtons.includes(index);
    }
    clearSelection() {
        this.selectedButtons.forEach((index) => {
            this.documentos[index] = null;
            this.documentosName[index] = '';
            const fileInput = document.getElementById('fileInput' + index);
            if (fileInput) {
                fileInput.value = '';
            }
        });
        this.selectedButtons = [];
    }
    getSessionID() {
        this.loading = true;
        this.screenLock = true;
        this.sessionIdApi.post(this.signalRService.host, this.idTotvsVision, this.idProjeto, this.listButtonsDocument).subscribe({
            next: (response) => {
                if (!response.sessionID) {
                    return;
                }
                this.sessionID = response.sessionID;
                this.myAngularxQrCode = `http:://localhost/tvision/app?SessionId=${response.sessionID}`;
                const tempoSession = new Date(response.createdAt);
                const expirationTime = new Date(tempoSession.getTime() + 11 * 60000);
                this.startCountdown(expirationTime);
                const objectOCR = {
                    sessionID: response.sessionID,
                    createdAt: response.createdAt
                };
                sessionStorage.setItem('totvsvisionocrdata', JSON.stringify(objectOCR));
                sessionStorage.setItem('totvsvisionocrqrCode', JSON.stringify(this.myAngularxQrCode));
                this.initializeSignalRConnection();
            },
            error: () => {
                this.loading = false;
                this.screenLock = false;
            },
            complete: () => {
                this.loading = false;
                this.screenLock = false;
            }
        });
    }
    startCountdown(expirationTime) {
        const updateCountdown = () => {
            const now = new Date();
            const timeLeft = expirationTime.getTime() - now.getTime();
            if (timeLeft <= 0) {
                this.sessionTimeLeft = 'Expirou';
                this.clearSessionID();
            }
            else {
                const minutesLeft = Math.floor(timeLeft / 60000);
                const secondsLeft = Math.floor((timeLeft % 60000) / 1000);
                this.sessionTimeLeft = `${minutesLeft}:${secondsLeft < 10 ? '0' : ''}${secondsLeft}`;
            }
        };
        updateCountdown();
        this.countdownInterval = setInterval(updateCountdown, 1000);
    }
    clearSessionID() {
        this.closeListModal();
        this.sessionID = null;
        this.ngOnDestroy();
        clearInterval(this.countdownInterval);
    }
    triggerFileInput(index) {
        const fileInput = document.getElementById('fileInput' + index);
        if (fileInput) {
            fileInput.click();
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOcrListComponent, deps: [{ token: SignalRService }, { token: SessionIdApi }, { token: i3.PoNotificationService }, { token: i4.NgxImageCompressService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.12", type: TotvsVisionOcrListComponent, isStandalone: true, selector: "totvs-vision-ocr-list", inputs: { idTotvsVision: "idTotvsVision", idProjeto: "idProjeto", listButtonsDocument: "listButtonsDocument" }, outputs: { informacaoEnviada: "informacaoEnviada" }, viewQueries: [{ propertyName: "listModal", first: true, predicate: PoModalComponent, descendants: true, static: true }], ngImport: i0, template: "\r\n\r\n<po-modal #listModal p-title=\"Imagens a serem carregadas localmente\">\r\n    <po-loading-overlay\r\n      [hidden]=\"!loading\"\r\n      [p-screen-lock]=\"screenLock\">\r\n    </po-loading-overlay>\r\n  \r\n    @if(!this.loading && !this.screenLock) {\r\n      <div class=\"button-container\">\r\n        @if(this.sessionID == null) {\r\n          <p>Obtenha a licen\u00E7a do Totvs Vision</p>\r\n        } \r\n        @else {\r\n          @for (item of listButtonsDocument; track $index) {\r\n            <div class=\"button-wrapper\">\r\n              <input \r\n                  type=\"file\" \r\n                  class=\"file-input\" \r\n                  (change)=\"onFileSelected($event, this.listButtonsDocument[$index], $index)\" \r\n                  [id]=\"'fileInput' + $index\" \r\n                  accept=\"image/*\" \r\n                  hidden>\r\n              <div class=\"button-checkbox-container\">\r\n                <po-checkbox \r\n                  name=\"checkbox\" \r\n                  [ngModel]=\"isSelected($index)\"\r\n                  (ngModelChange)=\"onCheckboxChange($event, $index)\">\r\n                </po-checkbox>\r\n                <div class=\"button-with-filename\">\r\n                  <po-button \r\n                    [p-label]=\"this.listButtonsDocument[$index].nameButton\"\r\n                    (p-click)=\"triggerFileInput($index)\"\r\n                    p-icon=\"{{ this.documentos[$index] ? 'ph ph-check' : '' }}\">\r\n                  </po-button>\r\n                  <div class=\"file-name\">{{ getShortFileName(documentosName[$index]) }}</div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          }\r\n      }\r\n      </div>\r\n      @if(this.sessionID != null) {\r\n        <div style=\"text-align: right;\">\r\n          Tempo restante: {{ sessionTimeLeft }}\r\n        </div>\r\n        <po-divider></po-divider>\r\n        <div style=\"text-align: right;\">\r\n          <po-button\r\n            p-label=\"Enviar Imagens\"\r\n            p-kind=\"primary\"\r\n            (p-click)=\"enviarImagens()\">\r\n          </po-button>\r\n          <po-button\r\n            p-label=\"Limpar Sele\u00E7\u00E3o\"\r\n            p-kind=\"tertiary\"\r\n            [p-disabled]=\"this.selectedButtons.length == 0\"\r\n            (p-click)=\"clearSelection()\">\r\n          </po-button>\r\n          <po-button\r\n            p-label=\"Limpar Tudo\"\r\n            p-kind=\"tertiary\"\r\n            (p-click)=\"limparImagens()\">\r\n          </po-button>\r\n        </div>\r\n      }\r\n    }\r\n  </po-modal>\r\n  ", styles: [".button-container{display:flex;flex-wrap:wrap;gap:10px}.button-wrapper{display:flex;flex-direction:column;align-items:center}.button-checkbox-container{display:flex;align-items:baseline;gap:5px}.button-with-filename{display:flex;flex-direction:column;align-items:center}.custom-checkbox{margin-right:5px}.file-input{display:none}.file-name{margin-top:5px;font-size:.9em;color:#333;max-width:80px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}:host ::ng-deep .po-button[p-kind=secondary]{color:#045b8f!important;border-color:#045b8f!important;outline:none}:host ::ng-deep .po-button[p-kind=primary]{background-color:#007bff!important;margin-top:15px;margin-right:10px;outline:none}:host ::ng-deep .po-button[p-kind=tertiary]{color:#d60808!important;border-color:#d60808!important;margin-top:15px;margin-right:10px;outline:none}\n"], dependencies: [{ kind: "ngmodule", type: PoModule }, { kind: "component", type: i3.PoButtonComponent, selector: "po-button" }, { kind: "component", type: i3.PoDividerComponent, selector: "po-divider" }, { kind: "component", type: i3.PoCheckboxComponent, selector: "po-checkbox" }, { kind: "component", type: i3.PoLoadingOverlayComponent, selector: "po-loading-overlay" }, { kind: "component", type: i3.PoModalComponent, selector: "po-modal" }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i5.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i5.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOcrListComponent, decorators: [{
            type: Component,
            args: [{ selector: 'totvs-vision-ocr-list', standalone: true, imports: [PoModule, FormsModule], template: "\r\n\r\n<po-modal #listModal p-title=\"Imagens a serem carregadas localmente\">\r\n    <po-loading-overlay\r\n      [hidden]=\"!loading\"\r\n      [p-screen-lock]=\"screenLock\">\r\n    </po-loading-overlay>\r\n  \r\n    @if(!this.loading && !this.screenLock) {\r\n      <div class=\"button-container\">\r\n        @if(this.sessionID == null) {\r\n          <p>Obtenha a licen\u00E7a do Totvs Vision</p>\r\n        } \r\n        @else {\r\n          @for (item of listButtonsDocument; track $index) {\r\n            <div class=\"button-wrapper\">\r\n              <input \r\n                  type=\"file\" \r\n                  class=\"file-input\" \r\n                  (change)=\"onFileSelected($event, this.listButtonsDocument[$index], $index)\" \r\n                  [id]=\"'fileInput' + $index\" \r\n                  accept=\"image/*\" \r\n                  hidden>\r\n              <div class=\"button-checkbox-container\">\r\n                <po-checkbox \r\n                  name=\"checkbox\" \r\n                  [ngModel]=\"isSelected($index)\"\r\n                  (ngModelChange)=\"onCheckboxChange($event, $index)\">\r\n                </po-checkbox>\r\n                <div class=\"button-with-filename\">\r\n                  <po-button \r\n                    [p-label]=\"this.listButtonsDocument[$index].nameButton\"\r\n                    (p-click)=\"triggerFileInput($index)\"\r\n                    p-icon=\"{{ this.documentos[$index] ? 'ph ph-check' : '' }}\">\r\n                  </po-button>\r\n                  <div class=\"file-name\">{{ getShortFileName(documentosName[$index]) }}</div>\r\n                </div>\r\n              </div>\r\n            </div>\r\n          }\r\n      }\r\n      </div>\r\n      @if(this.sessionID != null) {\r\n        <div style=\"text-align: right;\">\r\n          Tempo restante: {{ sessionTimeLeft }}\r\n        </div>\r\n        <po-divider></po-divider>\r\n        <div style=\"text-align: right;\">\r\n          <po-button\r\n            p-label=\"Enviar Imagens\"\r\n            p-kind=\"primary\"\r\n            (p-click)=\"enviarImagens()\">\r\n          </po-button>\r\n          <po-button\r\n            p-label=\"Limpar Sele\u00E7\u00E3o\"\r\n            p-kind=\"tertiary\"\r\n            [p-disabled]=\"this.selectedButtons.length == 0\"\r\n            (p-click)=\"clearSelection()\">\r\n          </po-button>\r\n          <po-button\r\n            p-label=\"Limpar Tudo\"\r\n            p-kind=\"tertiary\"\r\n            (p-click)=\"limparImagens()\">\r\n          </po-button>\r\n        </div>\r\n      }\r\n    }\r\n  </po-modal>\r\n  ", styles: [".button-container{display:flex;flex-wrap:wrap;gap:10px}.button-wrapper{display:flex;flex-direction:column;align-items:center}.button-checkbox-container{display:flex;align-items:baseline;gap:5px}.button-with-filename{display:flex;flex-direction:column;align-items:center}.custom-checkbox{margin-right:5px}.file-input{display:none}.file-name{margin-top:5px;font-size:.9em;color:#333;max-width:80px;overflow:hidden;white-space:nowrap;text-overflow:ellipsis}:host ::ng-deep .po-button[p-kind=secondary]{color:#045b8f!important;border-color:#045b8f!important;outline:none}:host ::ng-deep .po-button[p-kind=primary]{background-color:#007bff!important;margin-top:15px;margin-right:10px;outline:none}:host ::ng-deep .po-button[p-kind=tertiary]{color:#d60808!important;border-color:#d60808!important;margin-top:15px;margin-right:10px;outline:none}\n"] }]
        }], ctorParameters: () => [{ type: SignalRService }, { type: SessionIdApi }, { type: i3.PoNotificationService }, { type: i4.NgxImageCompressService }], propDecorators: { idTotvsVision: [{
                type: Input
            }], idProjeto: [{
                type: Input
            }], listButtonsDocument: [{
                type: Input
            }], informacaoEnviada: [{
                type: Output
            }], listModal: [{
                type: ViewChild,
                args: [PoModalComponent, { static: true }]
            }] } });

class TotvsVisionOcrQRCodeComponent {
    ngOnDestroy() {
        if (this.sessionID) {
            this.signalRService.leaveSession(this.sessionID);
            sessionStorage.removeItem('totvsvisionocrdata');
        }
    }
    ngOnInit() {
        this.signalRService.host = "http://127.0.0.1:5002";
        this.validateSession();
        this.openQrCodeModal();
        this.initializeSignalRConnection();
    }
    closeQrCodeModal() {
        if (this.qrCodeModal) {
            this.qrCodeModal.close();
        }
    }
    openQrCodeModal() {
        if (this.sessionID === null) {
            this.getSessionID();
        }
        if (this.qrCodeModal) {
            this.qrCodeModal.open();
        }
    }
    constructor(signalRService, sessionIdApi, poNotificationService) {
        this.signalRService = signalRService;
        this.sessionIdApi = sessionIdApi;
        this.poNotificationService = poNotificationService;
        this.idTotvsVision = '';
        this.idProjeto = '';
        this.listButtonsDocument = [];
        this.informacaoEnviada = new EventEmitter();
        this.loading = false;
        this.screenLock = false;
        this.sessionID = null;
        this.sessionTimeLeft = '';
        this.myAngularxQrCode = sessionStorage.getItem('totvsvisionocrqrCode') ?? '';
    }
    async initializeSignalRConnection() {
        try {
            if (this.sessionID && this.idProjeto) {
                this.signalRService.initializeConnection(this.idProjeto);
                this.signalRService.startConnection().then(() => {
                    this.joinSession(this.sessionID ?? "");
                }).catch(err => console.error(err));
                this.signalRService.messageReceived.subscribe((data) => {
                    this.informacaoEnviada.emit(data);
                });
                this.signalRService.listenForMessageUnique();
            }
        }
        catch (error) {
            this.clearSessionID();
            console.error(error);
        }
    }
    joinSession(sessionID) {
        this.signalRService.joinSession(sessionID).then().catch(err => console.error(err));
    }
    validateSession() {
        const ocr = sessionStorage.getItem('totvsvisionocrdata');
        if (!ocr) {
            return;
        }
        const objectOCR = JSON.parse(ocr);
        this.sessionID = objectOCR.sessionID;
        const expirationTime = new Date(objectOCR.createdAt);
        expirationTime.setMinutes(expirationTime.getMinutes() + 11);
        this.startCountdown(expirationTime);
    }
    getSessionID() {
        if (this.listButtonsDocument.length === 0) {
            this.poNotificationService.error('Nenhum documento criado');
            return;
        }
        this.loading = true;
        this.screenLock = true;
        this.sessionIdApi.post(this.signalRService.host, this.idTotvsVision, this.idProjeto, this.listButtonsDocument).subscribe({
            next: (response) => {
                if (!response.sessionID) {
                    return;
                }
                this.sessionID = response.sessionID;
                this.myAngularxQrCode = `http:://localhost/tvision/app?SessionId=${response.sessionID}`;
                const tempoSession = new Date(response.createdAt);
                const expirationTime = new Date(tempoSession.getTime() + 11 * 60000);
                this.startCountdown(expirationTime);
                const objectOCR = {
                    sessionID: response.sessionID,
                    createdAt: response.createdAt
                };
                sessionStorage.setItem('totvsvisionocrdata', JSON.stringify(objectOCR));
                sessionStorage.setItem('totvsvisionocrqrCode', JSON.stringify(this.myAngularxQrCode));
                this.initializeSignalRConnection();
            },
            error: () => {
                this.loading = false;
                this.screenLock = false;
            },
            complete: () => {
                this.loading = false;
                this.screenLock = false;
            }
        });
    }
    startCountdown(expirationTime) {
        const updateCountdown = () => {
            const now = new Date();
            const timeLeft = expirationTime.getTime() - now.getTime();
            if (timeLeft <= 0) {
                this.sessionTimeLeft = 'Expirou';
                this.clearSessionID();
            }
            else {
                const minutesLeft = Math.floor(timeLeft / 60000);
                const secondsLeft = Math.floor((timeLeft % 60000) / 1000);
                this.sessionTimeLeft = `${minutesLeft}:${secondsLeft < 10 ? '0' : ''}${secondsLeft}`;
            }
        };
        updateCountdown();
        this.countdownInterval = setInterval(updateCountdown, 1000);
    }
    clearSessionID() {
        this.closeQrCodeModal();
        this.sessionID = null;
        this.ngOnDestroy();
        clearInterval(this.countdownInterval);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOcrQRCodeComponent, deps: [{ token: SignalRService }, { token: SessionIdApi }, { token: i3.PoNotificationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.12", type: TotvsVisionOcrQRCodeComponent, isStandalone: true, selector: "totvs-vision-ocr-qr-code", inputs: { idTotvsVision: "idTotvsVision", idProjeto: "idProjeto", listButtonsDocument: "listButtonsDocument" }, outputs: { informacaoEnviada: "informacaoEnviada" }, viewQueries: [{ propertyName: "qrCodeModal", first: true, predicate: PoModalComponent, descendants: true, static: true }], ngImport: i0, template: "<po-modal #qrCodeModal p-title=\"QR Code\">\r\n    <po-loading-overlay\r\n      [hidden]=\"!loading\"\r\n      [p-screen-lock]=\"screenLock\">\r\n    </po-loading-overlay>\r\n    @if(!this.loading && !this.screenLock) {\r\n      <div style=\"text-align: center;\">\r\n        @if(this.sessionID == null) {\r\n          <p>Obtenha a licen\u00E7a do Totvs Vision</p>\r\n        } \r\n        @else {\r\n          <qrcode [qrdata]=\"myAngularxQrCode\" [width]=\"256\" [errorCorrectionLevel]=\"'M'\"></qrcode>\r\n        }    \r\n      </div>\r\n      @if(this.sessionID != null) {\r\n        <div style=\"text-align: right;\">\r\n          Tempo restante: {{ sessionTimeLeft }}\r\n        </div>\r\n      }\r\n    }\r\n</po-modal>", styles: [":host ::ng-deep .po-button[p-kind=secondary]{color:#797979!important;border-color:#797979!important;outline:none}:host ::ng-deep .po-button[p-kind=primary]{background-color:#007bff!important;margin-top:25px;margin-right:10px;outline:none}:host ::ng-deep .po-button[p-kind=tertiary]{color:#d60808!important;border-color:#d60808!important;margin-top:25px;outline:none}\n"], dependencies: [{ kind: "ngmodule", type: PoModule }, { kind: "component", type: i3.PoLoadingOverlayComponent, selector: "po-loading-overlay" }, { kind: "component", type: i3.PoModalComponent, selector: "po-modal" }, { kind: "ngmodule", type: QRCodeModule }, { kind: "component", type: i4$1.QRCodeComponent, selector: "qrcode", inputs: ["allowEmptyString", "colorDark", "colorLight", "cssClass", "elementType", "errorCorrectionLevel", "imageSrc", "imageHeight", "imageWidth", "margin", "qrdata", "scale", "version", "width", "alt", "ariaLabel", "title"], outputs: ["qrCodeURL"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOcrQRCodeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'totvs-vision-ocr-qr-code', standalone: true, imports: [PoModule, QRCodeModule], template: "<po-modal #qrCodeModal p-title=\"QR Code\">\r\n    <po-loading-overlay\r\n      [hidden]=\"!loading\"\r\n      [p-screen-lock]=\"screenLock\">\r\n    </po-loading-overlay>\r\n    @if(!this.loading && !this.screenLock) {\r\n      <div style=\"text-align: center;\">\r\n        @if(this.sessionID == null) {\r\n          <p>Obtenha a licen\u00E7a do Totvs Vision</p>\r\n        } \r\n        @else {\r\n          <qrcode [qrdata]=\"myAngularxQrCode\" [width]=\"256\" [errorCorrectionLevel]=\"'M'\"></qrcode>\r\n        }    \r\n      </div>\r\n      @if(this.sessionID != null) {\r\n        <div style=\"text-align: right;\">\r\n          Tempo restante: {{ sessionTimeLeft }}\r\n        </div>\r\n      }\r\n    }\r\n</po-modal>", styles: [":host ::ng-deep .po-button[p-kind=secondary]{color:#797979!important;border-color:#797979!important;outline:none}:host ::ng-deep .po-button[p-kind=primary]{background-color:#007bff!important;margin-top:25px;margin-right:10px;outline:none}:host ::ng-deep .po-button[p-kind=tertiary]{color:#d60808!important;border-color:#d60808!important;margin-top:25px;outline:none}\n"] }]
        }], ctorParameters: () => [{ type: SignalRService }, { type: SessionIdApi }, { type: i3.PoNotificationService }], propDecorators: { idTotvsVision: [{
                type: Input
            }], idProjeto: [{
                type: Input
            }], listButtonsDocument: [{
                type: Input
            }], informacaoEnviada: [{
                type: Output
            }], qrCodeModal: [{
                type: ViewChild,
                args: [PoModalComponent, { static: true }]
            }] } });

class TotvsVisionOCRComponent {
    constructor(signalRService) {
        this.signalRService = signalRService;
        this.listButtonsDocument = [];
        this.idTotvsVision = '';
        this.idProjeto = '';
        this.sidebarBgColor = 'transparent';
        this.isCollapsed = false;
        this.informacaoEnviada = new EventEmitter();
        this.habilitarQrCode = false;
        this.habilitarLista = false;
        this.sidebarBgColorAux = 'transparent';
    }
    ngOnInit() {
        this.signalRService.host = "https://iarmfunctions20240504113316.azurewebsites.net/";
        this.toggleSidebar();
    }
    openQrCodeModal() {
        this.habilitarQrCode = true;
        this.qrCodeModal?.ngOnInit();
    }
    openListModal() {
        this.habilitarLista = true;
        this.listModal?.ngOnInit();
    }
    receberInformacao(informacao) {
        this.informacaoEnviada.emit(informacao);
    }
    toggleSidebar() {
        this.isCollapsed = !this.isCollapsed;
        if (this.sidebarBgColor !== 'transparent') {
            this.sidebarBgColorAux = this.sidebarBgColor;
        }
        this.sidebarBgColor = this.isCollapsed ? 'transparent' : this.sidebarBgColorAux;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOCRComponent, deps: [{ token: SignalRService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.12", type: TotvsVisionOCRComponent, isStandalone: true, selector: "totvs-vision-ocr", inputs: { listButtonsDocument: "listButtonsDocument", idTotvsVision: "idTotvsVision", idProjeto: "idProjeto", sidebarBgColor: "sidebarBgColor", isCollapsed: "isCollapsed" }, outputs: { informacaoEnviada: "informacaoEnviada" }, viewQueries: [{ propertyName: "qrCodeModal", first: true, predicate: ["qrCodeModal"], descendants: true }, { propertyName: "listModal", first: true, predicate: ["listModal"], descendants: true }], ngImport: i0, template: "<div class=\"sidebar\" [class.collapsed]=\"isCollapsed\" [ngStyle]=\"{'background-color': sidebarBgColor}\">\r\n  <div class=\"icons-wrapper\">\r\n    <button class=\"icon\" (click)=\"openQrCodeModal()\">\r\n      <i class=\"ph ph-qr-code\"></i>\r\n      <span class=\"tooltip\">QrCode</span>\r\n    </button>\r\n\r\n    @if(this.habilitarQrCode) {\r\n      <totvs-vision-ocr-qr-code #qrCodeModal\r\n      [idTotvsVision]=\"idTotvsVision\"\r\n      [idProjeto]=\"idProjeto\"\r\n      [listButtonsDocument]=\"listButtonsDocument\">\r\n      </totvs-vision-ocr-qr-code>\r\n    }\r\n\r\n    <button class=\"icon\" (click)=\"openListModal()\">\r\n      <i class=\"ph ph-list-checks\"></i>\r\n      <span class=\"tooltip\">Lista</span>\r\n    </button>\r\n\r\n    @if(this.habilitarLista) {\r\n      <totvs-vision-ocr-list #listModal\r\n        [idTotvsVision]=\"idTotvsVision\"\r\n        [idProjeto]=\"idProjeto\"\r\n        [listButtonsDocument]=\"listButtonsDocument\"\r\n        (informacaoEnviada)=\"receberInformacao({ menssagem\r\n          : $event.menssagem, uniqueKey: $event.uniqueKey})\">\r\n      </totvs-vision-ocr-list>\r\n    }\r\n  </div>\r\n  <button class=\"icon toggle\" (click)=\"toggleSidebar()\" aria-label=\"Expandir/Colapsar Barra Lateral\">\r\n    <i class=\"ph\" [ngClass]=\"isCollapsed ? 'ph-caret-left' : 'ph-caret-right'\"></i>\r\n    <span class=\"tooltip\">Expandir</span>\r\n  </button>\r\n</div>", styles: [":host{display:flex}.sidebar{width:50px;background-color:transparent;height:100vh;padding:10px 0;border-left:1px solid #ddd;display:flex;flex-direction:column;align-items:center;transition:width .3s,border-left .3s;position:fixed;right:0;top:0;z-index:1000}.sidebar.collapsed{width:20px;border-left:none}.icon{width:24px;height:24px;background-size:cover;margin:20px 0;cursor:pointer;position:relative;border:none;background-color:transparent;background-image:none;display:flex;flex-direction:column;align-items:center;padding:0}.icon span.tooltip{visibility:hidden;width:max-content;background-color:#555;color:#fff;text-align:center;border-radius:6px;padding:5px 8px;position:absolute;z-index:1;top:50%;left:calc(-100% - 10px);transform:translateY(-50%);opacity:0;transition:opacity .3s}.icon span.tooltip:after{content:\"\";position:absolute;top:50%;right:-5px;transform:translateY(-50%);border-width:5px;border-style:solid;border-color:transparent transparent transparent #555}.icon:hover span.tooltip{visibility:visible;opacity:1}.toggle{position:absolute;bottom:10px;width:50px;border:none;background:none;cursor:pointer;padding:10px;display:flex;flex-direction:column;align-items:center}.toggle i{font-size:30px}.icons-wrapper{display:flex;flex-direction:column;align-items:center;transition:opacity .3s}.sidebar.collapsed .icons-wrapper{opacity:0}.sidebar.collapsed .toggle{opacity:1}.icon i{font-size:2rem;color:#333;display:block;width:3rem;height:3rem}@media (max-width: 768px){.sidebar{width:40px}.sidebar.collapsed{width:15px}.toggle{width:40px;font-size:26px}.icon{width:20px;height:20px;margin:15px 0}}@media (max-width: 480px){.sidebar{width:30px}.sidebar.collapsed{width:10px}.toggle{width:30px;font-size:22px}.icon{width:18px;height:18px;margin:10px 0}}@media (max-width: 320px){.sidebar{width:25px}.sidebar.collapsed{width:8px}.toggle{width:25px;font-size:18px}.icon{width:16px;height:16px;margin:8px 0}.icon span.tooltip{font-size:.8rem;padding:4px 6px}}\n"], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "ngmodule", type: QRCodeModule }, { kind: "ngmodule", type: PoModule }, { kind: "component", type: TotvsVisionOcrListComponent, selector: "totvs-vision-ocr-list", inputs: ["idTotvsVision", "idProjeto", "listButtonsDocument"], outputs: ["informacaoEnviada"] }, { kind: "component", type: TotvsVisionOcrQRCodeComponent, selector: "totvs-vision-ocr-qr-code", inputs: ["idTotvsVision", "idProjeto", "listButtonsDocument"], outputs: ["informacaoEnviada"] }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.12", ngImport: i0, type: TotvsVisionOCRComponent, decorators: [{
            type: Component,
            args: [{ selector: 'totvs-vision-ocr', standalone: true, imports: [CommonModule, QRCodeModule, PoModule, TotvsVisionOcrListComponent, TotvsVisionOcrQRCodeComponent], template: "<div class=\"sidebar\" [class.collapsed]=\"isCollapsed\" [ngStyle]=\"{'background-color': sidebarBgColor}\">\r\n  <div class=\"icons-wrapper\">\r\n    <button class=\"icon\" (click)=\"openQrCodeModal()\">\r\n      <i class=\"ph ph-qr-code\"></i>\r\n      <span class=\"tooltip\">QrCode</span>\r\n    </button>\r\n\r\n    @if(this.habilitarQrCode) {\r\n      <totvs-vision-ocr-qr-code #qrCodeModal\r\n      [idTotvsVision]=\"idTotvsVision\"\r\n      [idProjeto]=\"idProjeto\"\r\n      [listButtonsDocument]=\"listButtonsDocument\">\r\n      </totvs-vision-ocr-qr-code>\r\n    }\r\n\r\n    <button class=\"icon\" (click)=\"openListModal()\">\r\n      <i class=\"ph ph-list-checks\"></i>\r\n      <span class=\"tooltip\">Lista</span>\r\n    </button>\r\n\r\n    @if(this.habilitarLista) {\r\n      <totvs-vision-ocr-list #listModal\r\n        [idTotvsVision]=\"idTotvsVision\"\r\n        [idProjeto]=\"idProjeto\"\r\n        [listButtonsDocument]=\"listButtonsDocument\"\r\n        (informacaoEnviada)=\"receberInformacao({ menssagem\r\n          : $event.menssagem, uniqueKey: $event.uniqueKey})\">\r\n      </totvs-vision-ocr-list>\r\n    }\r\n  </div>\r\n  <button class=\"icon toggle\" (click)=\"toggleSidebar()\" aria-label=\"Expandir/Colapsar Barra Lateral\">\r\n    <i class=\"ph\" [ngClass]=\"isCollapsed ? 'ph-caret-left' : 'ph-caret-right'\"></i>\r\n    <span class=\"tooltip\">Expandir</span>\r\n  </button>\r\n</div>", styles: [":host{display:flex}.sidebar{width:50px;background-color:transparent;height:100vh;padding:10px 0;border-left:1px solid #ddd;display:flex;flex-direction:column;align-items:center;transition:width .3s,border-left .3s;position:fixed;right:0;top:0;z-index:1000}.sidebar.collapsed{width:20px;border-left:none}.icon{width:24px;height:24px;background-size:cover;margin:20px 0;cursor:pointer;position:relative;border:none;background-color:transparent;background-image:none;display:flex;flex-direction:column;align-items:center;padding:0}.icon span.tooltip{visibility:hidden;width:max-content;background-color:#555;color:#fff;text-align:center;border-radius:6px;padding:5px 8px;position:absolute;z-index:1;top:50%;left:calc(-100% - 10px);transform:translateY(-50%);opacity:0;transition:opacity .3s}.icon span.tooltip:after{content:\"\";position:absolute;top:50%;right:-5px;transform:translateY(-50%);border-width:5px;border-style:solid;border-color:transparent transparent transparent #555}.icon:hover span.tooltip{visibility:visible;opacity:1}.toggle{position:absolute;bottom:10px;width:50px;border:none;background:none;cursor:pointer;padding:10px;display:flex;flex-direction:column;align-items:center}.toggle i{font-size:30px}.icons-wrapper{display:flex;flex-direction:column;align-items:center;transition:opacity .3s}.sidebar.collapsed .icons-wrapper{opacity:0}.sidebar.collapsed .toggle{opacity:1}.icon i{font-size:2rem;color:#333;display:block;width:3rem;height:3rem}@media (max-width: 768px){.sidebar{width:40px}.sidebar.collapsed{width:15px}.toggle{width:40px;font-size:26px}.icon{width:20px;height:20px;margin:15px 0}}@media (max-width: 480px){.sidebar{width:30px}.sidebar.collapsed{width:10px}.toggle{width:30px;font-size:22px}.icon{width:18px;height:18px;margin:10px 0}}@media (max-width: 320px){.sidebar{width:25px}.sidebar.collapsed{width:8px}.toggle{width:25px;font-size:18px}.icon{width:16px;height:16px;margin:8px 0}.icon span.tooltip{font-size:.8rem;padding:4px 6px}}\n"] }]
        }], ctorParameters: () => [{ type: SignalRService }], propDecorators: { qrCodeModal: [{
                type: ViewChild,
                args: ['qrCodeModal']
            }], listModal: [{
                type: ViewChild,
                args: ['listModal']
            }], listButtonsDocument: [{
                type: Input
            }], idTotvsVision: [{
                type: Input
            }], idProjeto: [{
                type: Input
            }], sidebarBgColor: [{
                type: Input
            }], isCollapsed: [{
                type: Input
            }], informacaoEnviada: [{
                type: Output
            }] } });

/*
 * Public API Surface of totvs-vision-ocr
 */

/**
 * Generated bundle index. Do not edit.
 */

export { TotvsVisionOCRComponent, TotvsVisionOcrListComponent, TotvsVisionOcrQRCodeComponent };
//# sourceMappingURL=totvs-vision-ocr.mjs.map
